Common identifier types for OpenTalk crates
These types are usually re-exported in opentalk-types-common, so this
crate is useless as a direct dependency in most cases, instead the
re-exported types should be used.
Modules
- asset_
file_ kind - The kind of an asset, and some extra functionality around it.
- feature_
id - The id of a feature, and some extra functionality around it.
- module_
id - The id of a module, and some extra functionality around it.